==> nezha-compute-common-1.27.1002-20181227.121147-1-sources.jar: cn/com/duiba/nezha/compute/common/model/Test.java <==
package cn.com.duiba.nezha.compute.common.model;

import cn.com.duiba.nezha.compute.common.model.activityselect.ActivitySelector;
import cn.com.duiba.nezha.compute.common.model.activityselectchange.*;
import cn.com.duiba.nezha.compute.common.model.activityselectchange.BetaDistribution;
import com.hankcs.hanlp.dependency.nnparser.util.math;

import java.util.*;
import java.util.Comparator;



/**
 * Created by jiali on 2017/8/5.
 */
public class Test {


    public static Comparator<Double> iComparator = new Comparator<Double>() {
        @Override
        public int compare(Double c1, Double c2) {
            return (int) (c2 - c1 >= 0 ? 1 : -1);
        }
    };

    public static  double getTheta (double reward) {
         double decay=0.4;
         double count=0.0;

         //reward = reward * reward;
        //reward = Math.max(reward, 0.3);

        reward = reward * decay + reward;
        count = count * decay + 1.0;
        double alpha = 1.5 + reward;
        double beta = 2.0 + (count - reward);
        double theta = BetaDistribution.BetaDist(alpha,beta);
        return theta ;
    }

    public static  double getThetaWihtAlpBeta (double alpha,double beta) {

        double theta = BetaDistribution.BetaDist(alpha,beta);
        return theta ;
    }




    public static void main(String[] args) {

        boolean isGiveUp = false;
        double hourConvert = 300;
        double maxConvert = 2600;
        Calendar calendar = Calendar.getInstance();
        int minutes = 10;
        double speed = 0;
        if(minutes > 0)
        {
            speed = hourConvert / minutes;
            if(speed > 0.001) {
                double p = maxConvert / (speed * 60);
                isGiveUp = Math.random() > p ? true : false;
                if (hourConvert > maxConvert) isGiveUp = true;
                System.out.println(p);
            }
        }


        //test 2

         double hrequst=0;
         double arequst=0;
         double grequst=52155;

        double hcost=0;
        double acost=0;
        double gcost=490424;



        double hrpm=hrequst > 0 ? hcost / hrequst : 0.0;
        double arpm=arequst > 0 ? acost / arequst : 0.0;
        double grpm=grequst > 0 ? gcost / grequst : 0.0;


        double maxH=0.1;
        double sconfidence=  Math.min(hrequst / 60, 1);;
        double aconfidence=Math.min(arequst / 60, 1);;
        double maxA=0.1;
        double maxG=0.1;
        double decay=0.4;
        double maxRpm=50;
        double count=0.0;
        double reward = sconfidence * normlizeNew(hrpm, maxRpm, 1.0) +
                (1 - sconfidence) * aconfidence * normlizeNew(arpm , maxRpm, 0.9) +
                (1 - sconfidence - (1 - sconfidence) * aconfidence) * normlizeNew(grpm , maxRpm, 0.8);


        double reward0=reward;

        //reward = reward * reward;
        //reward = Math.max(reward, 0.1);

        reward = reward * decay + reward;
        count = count * decay + 1.0;
        double alpha = 1.5 + reward;
        double beta = 2.0 + (count - reward);


        double theta = BetaDistribution.BetaDist(alpha,beta);


        System.out.println("test2_grpm= " + grpm);
        System.out.println("test2_reward0= " + reward0);
        System.out.println("test2_reward= " + reward);
        System.out.println("test2_count= " + count);
        System.out.println("test2_alpha= " + alpha);
        System.out.println("test2_beta= " + beta);

        int win1=0;
        int sameDiff=0;
        int cnt=10000 ;

        int cnt5=0 ;
        for (int i = 0; i < cnt; i++) {
            double reward1=0.5;
            double reward2= 0.4;
            double reward3=0.3;
            double reward4=0.2;
            double reward5=0.1;

            double theta1=getTheta(reward1);
            double theta2=getTheta(reward2);
            double theta3=getTheta(reward3);
            double theta4=getTheta(reward4);
            double theta5=getTheta(reward5);

            if (theta5 >= theta1 && theta5 >= theta2 && theta5 >= theta3
                    && theta5 >= theta4 ) {
                cnt5 +=1 ;
            }


            if (theta5 > theta2) {
                win1  += 1;
            }
            if (Math.abs(theta1 - theta2) >=0.06) {
                sameDiff += 1;
            }


        }

        System.out.println("win1= " + win1);
        System.out.println("sameDiff= " + sameDiff);
        System.out.println("win1ratio= " + win1/(cnt+0.0));
        System.out.println("cnt5= " + cnt5);


        int win1111=0;
        int sameDiff111=0;
        int cnt1=10000;
        double maxTheat=0.0 ;

        int win91=0;
        int win92=0;
        int win93=0;
        int win94=0;
        int win95=0;

        int win95all=0;
        int win91all=0 ;

        for (int i = 0; i < cnt1; i++) {
            double alpha1 = 1.5;
            double beta1 = 37.99999999999955;

            double alpha2 = 65.49999999999966;
            double beta2 = 37.99999999999955;


            double alpha3 = 65.49999999999966;
            double beta3 = 37.99999999999955;

            double alpha4 = 65.49999999999966;
            double beta4 = 37.99999999999955;


            double alpha5 = 1.6;
            double beta5 = 2.9;


            double theta1 = getThetaWihtAlpBeta(alpha1, beta1);
            maxTheat = Math.max(theta1,maxTheat);
            //System.out.println("maxTheat1= " + maxTheat);
            //System.out.println("theta1= " + theta1);

            double theta2 = getThetaWihtAlpBeta(alpha2, beta2);
           // maxTheat = Math.max(theta2,maxTheat);
           // System.out.println("maxTheat2= " + maxTheat);

            double theta3 = getThetaWihtAlpBeta(alpha3, beta3);
            maxTheat = Math.max(theta3,maxTheat);
            //System.out.println("maxTheat3= " + maxTheat);

            double theta5 = getThetaWihtAlpBeta(alpha5, beta5);
            //System.out.println("theta5= " + theta5);
            maxTheat = Math.max(theta5,maxTheat);
            //System.out.println("maxTheat5= " + maxTheat);

            double theta4 = getThetaWihtAlpBeta(alpha4, beta4);
            maxTheat = Math.max(theta4,maxTheat);
            //System.out.println("maxTheat4= " + maxTheat);

            if (theta5 >= theta1 && theta5 >= theta2 && theta5 >= theta3
                    && theta5 >= theta4 ) {
                win95all +=1 ;
            }


            if (theta1 >= theta2 && theta1 >= theta3 && theta1 >= theta4
                    && theta1 >= theta5 ) {
                win91all +=1 ;
            }


            if (maxTheat ==theta1) {
                win91 += 1 ;
            }

            else if (maxTheat ==theta2) {
                win92 += 1 ;
            }

           else if (maxTheat ==theta3) {
                win93 += 1 ;
            }


            else if (maxTheat ==theta4) {
                win94 += 1 ;
            }

            else if (maxTheat ==theta5) {
                win95 += 1 ;
            }

        }


        System.out.println("win91= " + win91);
        System.out.println("win92= " + win92);
        System.out.println("win93= " + win93);
        System.out.println("win94= " + win94);
        System.out.println("win95= " + win95);
        System.out.println("maxTheat= " + maxTheat);


     System.out.println("win95ratio= " + win95/(cnt1+0.0));

        System.out.println("win95all= " + win95all);

        System.out.println("win91all= " + win91all);



        double a=normlize( 0.1, 0.1, 0.8);
        System.out.println("a= " + a);
        }




    static  double normlize(double val, double  max, double limit)
    {
        double norm = Math.min(val*limit/max, limit);
        return norm;
    }

    public static double normlizeNew(double val, double maxRpm, double limit) {
        double norm = Math.min(val/maxRpm, limit);
        return norm;
    }






}

==> nezha-compute-common-1.27.1004-20190110.074747-1-sources.jar: cn/com/duiba/nezha/compute/common/model/Test.java <==
package cn.com.duiba.nezha.compute.common.model;

import cn.com.duiba.nezha.compute.common.model.activityselect.ActivitySelector;
import cn.com.duiba.nezha.compute.common.model.activityselectchange.*;
import cn.com.duiba.nezha.compute.common.model.activityselectchange.BetaDistribution;
import com.hankcs.hanlp.dependency.nnparser.util.math;

import java.util.*;
import java.util.Comparator;

import static java.util.Objects.hash;


/**
 * Created by jiali on 2017/8/5.
 */
public class Test {


    public static Comparator<Double> iComparator = new Comparator<Double>() {
        @Override
        public int compare(Double c1, Double c2) {
            return (int) (c2 - c1 >= 0 ? 1 : -1);
        }
    };

    public static  double getTheta (double reward) {
         double decay=0.4;
         double count=0.0;

         //reward = reward * reward;
        //reward = Math.max(reward, 0.3);

        reward = reward * decay + reward;
        count = count * decay + 1.0;
        double alpha = 1.5 + reward;
        double beta = 2.0 + (count - reward);
        double theta = BetaDistribution.BetaDist(alpha,beta);
        return theta ;
    }

    public static  double getThetaWihtAlpBeta (double alpha,double beta) {

        double theta = BetaDistribution.BetaDist(alpha,beta);
        return theta ;
    }




    public static void main(String[] args) {

        boolean isGiveUp = false;
        double hourConvert = 300;
        double maxConvert = 2600;
        Calendar calendar = Calendar.getInstance();
        int minutes = 10;
        double speed = 0;
        if(minutes > 0)
        {
            speed = hourConvert / minutes;
            if(speed > 0.001) {
                double p = maxConvert / (speed * 60);
                isGiveUp = Math.random() > p ? true : false;
                if (hourConvert > maxConvert) isGiveUp = true;
                System.out.println(p);
            }
        }


        //test 2

         double hrequst=0;
         double arequst=0;
         double grequst=52155;

        double hcost=0;
        double acost=0;
        double gcost=490424;



        double hrpm=hrequst > 0 ? hcost / hrequst : 0.0;
        double arpm=arequst > 0 ? acost / arequst : 0.0;
        double grpm=grequst > 0 ? gcost / grequst : 0.0;


        double maxH=0.1;
        double sconfidence=  Math.min(hrequst / 60, 1);;
        double aconfidence=Math.min(arequst / 60, 1);;
        double maxA=0.1;
        double maxG=0.1;
        double decay=0.995;
        double maxRpm=50;
        double count=0.0;
        double reward = sconfidence * normlizeNew(hrpm, maxRpm, 1.0) +
                (1 - sconfidence) * aconfidence * normlizeNew(arpm , maxRpm, 0.9) +
                (1 - sconfidence - (1 - sconfidence) * aconfidence) * normlizeNew(grpm , maxRpm, 0.8);


        double reward0=reward;

        //reward = reward * reward;
        //reward = Math.max(reward, 0.1);

        reward = reward * decay + reward;
        count = count * decay + 1.0;
        double alpha = 1.5 + reward;
        double beta = 2.0 + (count - reward);


        double theta = BetaDistribution.BetaDist(alpha,beta);


        System.out.println("test2_grpm= " + grpm);
        System.out.println("test2_reward0= " + reward0);
        System.out.println("test2_reward= " + reward);
        System.out.println("test2_count= " + count);
        System.out.println("test2_alpha= " + alpha);
        System.out.println("test2_beta= " + beta);

        int win1=0;
        int sameDiff=0;
        int cnt=10000 ;

        int cnt5=0 ;
        for (int i = 0; i < cnt; i++) {
            double reward1=0.5;
            double reward2= 0.4;
            double reward3=0.3;
            double reward4=0.2;
            double reward5=0.1;

            double theta1=getTheta(reward1);
            double theta2=getTheta(reward2);
            double theta3=getTheta(reward3);
            double theta4=getTheta(reward4);
            double theta5=getTheta(reward5);

            if (theta5 >= theta1 && theta5 >= theta2 && theta5 >= theta3
                    && theta5 >= theta4 ) {
                cnt5 +=1 ;
            }


            if (theta5 > theta2) {
                win1  += 1;
            }
            if (Math.abs(theta1 - theta2) >=0.06) {
                sameDiff += 1;
            }


        }

        System.out.println("win1= " + win1);
        System.out.println("sameDiff= " + sameDiff);
        System.out.println("win1ratio= " + win1/(cnt+0.0));
        System.out.println("cnt5= " + cnt5);


        int win1111=0;
        int sameDiff111=0;
        int cnt1=10000;
        double maxTheat=0.0 ;

        int win91=0;
        int win92=0;
        int win93=0;
        int win94=0;
        int win95=0;

        int win95all=0;
        int win91all=0 ;

        for (int i = 0; i < cnt1; i++) {
            double alpha1 = 1.7;
            double beta1 = 2.8;

            double alpha2 = 1.8;
            double beta2 = 2.9;


            double alpha3 = 28;
            double beta3 = 45;

            double alpha4 = 65.49999999999966;
            double beta4 = 37.99999999999955;


            double alpha5 = 1.6;
            double beta5 = 2.9;


            double theta1 = getThetaWihtAlpBeta(alpha1, beta1);
            maxTheat = Math.max(theta1,maxTheat);
            //System.out.println("maxTheat1= " + maxTheat);
            //System.out.println("theta1= " + theta1);

            double theta2 = getThetaWihtAlpBeta(alpha2, beta2);
           // maxTheat = Math.max(theta2,maxTheat);
           // System.out.println("maxTheat2= " + maxTheat);

            double theta3 = getThetaWihtAlpBeta(alpha3, beta3);
            maxTheat = Math.max(theta3,maxTheat);
            //System.out.println("maxTheat3= " + maxTheat);

            double theta5 = getThetaWihtAlpBeta(alpha5, beta5);
            //System.out.println("theta5= " + theta5);
            maxTheat = Math.max(theta5,maxTheat);
            //System.out.println("maxTheat5= " + maxTheat);

            double theta4 = getThetaWihtAlpBeta(alpha4, beta4);
            maxTheat = Math.max(theta4,maxTheat);
            //System.out.println("maxTheat4= " + maxTheat);

            if (theta5 >= theta1 && theta5 >= theta2 && theta5 >= theta3
                    && theta5 >= theta4 ) {
                win95all +=1 ;
            }


            if (theta1 >= theta2 && theta1 >= theta3 && theta1 >= theta4
                    && theta1 >= theta5 ) {
                win91all +=1 ;
            }


            if (maxTheat ==theta1) {
                win91 += 1 ;
            }

            else if (maxTheat ==theta2) {
                win92 += 1 ;
            }

           else if (maxTheat ==theta3) {
                win93 += 1 ;
            }


            else if (maxTheat ==theta4) {
                win94 += 1 ;
            }

            else if (maxTheat ==theta5) {
                win95 += 1 ;
            }

        }


        System.out.println("win91= " + win91);
        System.out.println("win92= " + win92);
        System.out.println("win93= " + win93);
        System.out.println("win94= " + win94);
        System.out.println("win95= " + win95);
        System.out.println("maxTheat= " + maxTheat);


     System.out.println("win95ratio= " + win95/(cnt1+0.0));

        System.out.println("win95all= " + win95all);

        System.out.println("win91all= " + win91all);

        String str="957AF4B6DED7BDD7969E83BF0328B8FC" ;   //正数
        String str2="1046DB066DB411640F70D8C918865919" ;
        System.out.println("win91all= " + win91all);


        double a=normlize( 0.1, 0.1, 0.8);
        System.out.println("a= " + a);
        System.out.println("hash(str)= " + str.hashCode());
        System.out.println("hash(str2)= " + str2.hashCode());
        }




    static  double normlize(double val, double  max, double limit)
    {
        double norm = Math.min(val*limit/max, limit);
        return norm;
    }

    public static double normlizeNew(double val, double maxRpm, double limit) {
        double norm = Math.min(val/maxRpm, limit);
        return norm;
    }






}
